@@ -1,6 +1,6 @@
 from .datafile import DataWriter, DataReader, ReadMode, Mode
 from .csvfile import CsvReader, CsvWriter
 from .excel import ExcelReader, ExcelWriter, sheets
-from .builder import open_reader, open_writer, list2csv, dict2csv, objects2csv, list2excel, \
+from .builder import open_reader, open_writer, list2csv, dict2csv, objects2csv, list2excel, equals, \
     dict2excel, objects2excel, csv2list, csv2dict, csv2objects, excel2list, \
     excel2dict, excel2objects, load, load_objs, load_dicts, load_lists, save, save_objs, save_dicts, save_lists, convert
